The MARK capture-recapture models that are currently
supported are provided in MarkModels.pdf which is installed in the RMark directory of your R library.
You can also find a list in MARK under Help/Data Types.
'
There is one limitation of this interface. All models
in this interface are developed via a design matrix approach rather than
coding the model structure via parameter index matrices (PIMS). In most
cases, a logit or other link is used by default which has implications for
ability of MARK to count the number of identifiable parameters (see
dipper for an example). However, beginning with v1.7.6 the
sin link is now supported if the formula specifies an identity design matrix
for the parameter.
Before you begin, you must have installed MARK
(http://www.cnr.colostate.edu/~gwhite/mark/mark.htm) on your computer
or at least have a current copy of MARK.EXE. As long as you selected the
default location for the MARK install (c:/Program Files/Mark), the
RMark library will be able to find it. If for some reason, you choose
to install it in a different location, see the note section in
mark for instructions on setting the variable MarkPath to
specify the path. In addition to installing MARK, you must have installed
the RMark library into the R library directory. Once done with those
tasks, run R and enter library(RMark) (or put it in your .First function) to
attach the library of functions.
The following is a categorical listing of the functions in the library with
a link to the help for each function. To start, read the help for functions
import.chdata and mark to learn how to import
your data and fit a simple model. The text files for the examples shown in
import.chdata are in the subdirectory data within the R Library
directory in RMark. Next look at the example data sets and analyses
dipper, edwards.eberhardt, and
example.data. After you see the structure of the examples and
the use of functions to fit a series of analyses, explore the remaining
functions under Model Fitting, Batch Analyses, Model Selection and Summary
and Display. If your data and models contain individual covariates, read
the section on Real Parameter Computation to learn how to compute estimates
of real parameters at various covariate values.
Input/Output data & results
import.chdata,read.mark.binary,
extract.mark.output
Exporting Models to MARK interface
Model Fitting
mark, process.data,
make.design.data, add.design.data,
make.mark.model, run.mark.model
merge_design.covariates
Batch analyses with functions
run.models, collect.models,
create.model.list, mark.wrapper
Summary and display
summary.mark, print.mark,
print.marklist, get.real,
compute.real, print.summary.mark
Model Selection/Goodness of fit
adjust.chat, adjust.parameter.count,
model.table , release.gof,
model.average
Real Parameter computation
find.covariates, fill.covariates,
compute.real , covariate.predictions
Utility and internal functions
collect.model.names, compute.design.data,
extract.mark.output, inverse.link,
deriv.inverse.link, setup.model,
setup.parameters, valid.parameters,
cleanup
For examples, see dipper for CJS and POPAN, see
example.data for CJS with multiple grouping variables, see
edwards.eberhardt for various closed-capture models, see
mstrata for Multistrata, and see Blackduck for
known fate. The latter two are examples of the use of
mark.wrapper for a shortcut approach to creating a series of
models. Other examples have been added for the various other models. In MarkModels.pdf it also
lists the name of examples that are provided for each model.