Learn R Programming

RMark (version 2.2.0)

extract.mark.output: Extract results from MARK output file (internal use)

Description

Extracts the lnl, AICc, npar, beta and real estimates and returns a list of these results for inclusion in the mark object. The elements beta and real are dataframes with fields estimate,se,lcl,ucl. This function was written for internal use and is called by run.mark.model. It is documented here for more advanced users that might want to modify the code or adapt for their own use.

Usage

extract.mark.output(out, model, adjust, realvcv = FALSE, vcvfile)

Arguments

out
output from MARK analysis (model$output)
model
mark model object
adjust
if TRUE, adjusts number of parameters (npar) to number of columns in design matrix, modifies AIC and records both
realvcv
if TRUE the vcv matrix of the real parameters is extracted and stored in the model results
vcvfile
name of vcv file output

Value

result: list of extracted output elements
lnl
-2xLog-likelihood
deviance
Difference between saturated model and lnl
npar
Number of model parameters
AICc
Small-sample corrected AIC value using npar and n
npar.unadjusted
Number of model parameters as reported by MARK if npar was adjusted
AICc.unadjusted
Small-sample corrected AIC value using npar.unadjusted and n
n
Effective sample size reported by MARK; used in AICc calculation
beta
Dataframe of beta parameters with fields: estimate, se, lcl, ucl
real
Dataframe of real parameters with fields: estimate, se, lcl, ucl
derived.vcv
variance-covariance matrix for derived parameters if any
covariate.values
dataframe with fields Variable and Value which are the covariate names and value used for real parameter estimates in the MARK output
singular
indices of beta parameters that are non-estimable or at a boundary
real.vcv
variance-covariance matrix for real parameters (simplified) if realvcv=TRUE

See Also

run.mark.model