mark(data, ddl = NULL, begin.time = 1, model.name = NULL, model = "CJS", title = "", model.parameters = list(), initial = NULL, design.parameters = list(), right = TRUE, groups = NULL, age.var = NULL, initial.ages = 0, age.unit = 1, time.intervals = NULL, nocc = NULL, output = TRUE, invisible = TRUE, adjust = TRUE, mixtures = 1, se = FALSE, filename = NULL, prefix = "mark", default.fixed = TRUE, silent = FALSE, retry = 0, options = NULL, brief = FALSE, realvcv = FALSE, delete = FALSE, external = FALSE, profile.int = FALSE, chat = NULL, reverse = FALSE, run = TRUE, input.links = NULL, parm.specific = FALSE, mlogit0 = FALSE, threads = -1, hessian = FALSE, accumulate = TRUE, allgroups = FALSE, strata.labels = NULL, counts = NULL, icvalues = NULL, wrap = TRUE)groups even if there are no observations in the
grouprerun.markindex is
the parameter index in the full parameter structure and value is the
fixed value for the real parameterpim.translation which
translate between all different and simplified pims, real.labels
which are labels for real parameters for full (non-simplified) pim structure
and links the link function names for the full parameter structure lnl |
|
| -2xLog Likelihood value | |
npar |
Number of parameters (always the number of columns in design matrix) |
npar.unadjusted |
|
| number of estimated parameters from MARK if different than npar | |
n |
effective sample size |
AICc |
|
| Small sample corrected AIC using npar | |
AICc.unadjusted |
Small sample corrected AIC using npar.unadjusted |
beta |
|
| data frame of beta parameters with estimate, se, lcl, ucl | |
real |
data frame of real parameters with estimate, se, lcl, ucl and fixed |
beta.vcv
|
|
| variance-covariance matrix for beta | |
derived |
dataframe of derived parameters if any |
derived.vcv |
|
| variance-covariance matrix for derived parameters if any | |
covariate.values |
dataframe with fields Variable and
Value |
| which are the covariate names and value used for real parameter | |
| estimates in the MARK output | |
singular |
|
| indices of beta parameters that are non-estimable or at a boundary | |
real.vcv |
variance-covariance matrix for real parameters (simplified) if realvcv=TRUE |
model.parameters) for each of the parameters in the
capture-recapture model being fitted to the data. It runs MARK.EXE (see note
below) and then imports the text output file and binary variance-covariance
file that were created. It extracts output values from the text file and
creates a list of results that is returned as part of the list (of class
mark) which is the return value for this function.The models that are currently supported are listed in MarkModels.pdf which you can find in the RMark sub-directory of your R Library. Also, they are listed under Help/Data Types in the MARK interface.
The function mark is a shell that calls 5 other functions in the following
order as needed: 1) process.data, 2)
make.design.data, 3) make.mark.model, 4)
run.mark.model, and 5) summary.mark. A MARK
model can be fitted with this function (mark) or by calling the
individual functions that it uses. The calling arguments for mark
are a compilation of the calling arguments for each of the functions it
calls (with some arguments renamed to avoid conflicts). If data is a
processed dataframe (see process.data) then it expects to find
a value for ddl. Likewise, if the data have not been processed, then
ddl should be NULL. This dual calling structure allows either a
single call approach for each model or alternatively for the data to be
processed and the design data (ddl) to be created once and then a
whole series of models can be analyzed without repeating those steps.
For descriptions of the arguments data, begin.time,
groups, age.var, initial.ages, age.unit,
time.intervals and mixtures see process.data.
For descriptions of ddl, design.parameters=parameters,
and right, see make.design.data.
For descriptions of model.name , model,
title,model.parameters=parameters ,
default.fixed , initial, options, see
make.mark.model.
And finally, for descriptions of arguments invisible, filename
and adjust,see run.mark.model.
output,silent, and retry are the only arguments
specific to mark. output controls whether a summary of the model
input and output are given(if output=TRUE). silent controls
whether errors are shown when fitting a model. retry controls the
number of times a model will be refitted with new starting values (uses 0)
when some parameters are determined to be non-estimable or at a boundary.
The latter is the only time it makes sense to retry with new starting values
but MARK cannot discern between these two instances. The indices of the beta
parameters that are "singular" are stored in results$singular.
make.mark.model, run.mark.model,
make.design.data, process.data,
summary.mark
data(dipper)
dipper.Phidot.pdot=mark(dipper,threads=1)
Run the code above in your browser using DataLab