Learn R Programming

RMark (version 2.2.0)

process.ch: Process release-recapture history data

Description

Creates needed constructs from the release-recapture history.

Usage

process.ch(ch, freq = NULL, all = FALSE)

Arguments

ch
Vector of character strings; each character string is composed of either a constant length sequence of single characters (01001) or the character string can be comma separated if more than a single character is used (1S,1W,0,2W). If comma separated, each string must contain a constant number of elements.
freq
Optional vector of frequencies for ch; if missing assumed to be a; if
all
FALSE is okay for cjs unless R code used to compute lnl instead of FORTRAN; must be true for js because it returns additional quantities needed for entry prob.

Value

nocc
number of capture occasions
freq
absolute value of frequency for each ch
first
vector of occasion numbers for first 1
last
vector of occasion numbers for last 1
loc
vector of indicators of a loss on capture if set to 1
chmat
capture history matrix
FtoL
1's from first (1) to last (1) and 0's elsewhere; only if all==TRUE
Fplus
1's from occasion after first (1) to nocc(last occasion); only if all==TRUE
Lplus
1's from occasion after last (1) to nocc; only if all==TRUE
L
1's from last (1) to nocc; only if all==TRUE