Learn R Programming

RMark (version 2.2.7)

read.mark.binary: Reads binary file output from MARK and returns a list of the results

Description

Window and linux versions to read binary files created by MARK

Usage

read.mark.binary(filespec, derived_labels)

Value

List of estimates, se, lcl, ucl and var-cov matrices for beta, real and derived estimates

beta

Dataframe for beta parameters containing estimates, se, lcl, ucl

beta.vcv

variance-covariance matrix for beta estimates

real

Dataframe for real parameters containing estimates, se, lcl, ucl

real.vcv

variance-covariance matrix for real estimates

derived

Dataframe for derived parameters (if any) containing estimates, se, lcl, ucl

derived.vcv

variance-covariance matrix for derived estimates (if any)

Arguments

filespec

Filename specification for binary output file from MARK;named here as markxxx.vcv

derived_labels

vector of labels for derived parameters; NULL if no derived parameters for model

Author

Jeff Laake

See Also

extract.mark.output