release.gof: Runs RELEASE for goodness of fit test
Description
Creates input file for RELEASE with the specified data, runs RELEASE and
extracts the summary results for TEST2 and TEST3. Output file is named
Releasennn.tmp where nnn is an increasing numeric value to create a unique
filename.
Usage
release.gof(data, invisible = TRUE, title = "Release-gof",
view = FALSE)
Value
results: a dataframe giving chi-square, degrees of freedom and P
value for TEST2, TEST3 and total of tests
# \donttest{# This example is excluded from testing to reduce package check timedata(dipper)
dipper.processed=process.data(dipper,groups=("sex"))
release.gof(dipper.processed)
# }